"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setFormErrors = void 0;
var deepCopy_1 = require("@cnamts/vue-dot/src/helpers/deepCopy");
/**
 * Set error-messages prop on the fields in error
 *
 * @param {FormErrors} formErrors The errors list for each fields from the api
 * @param {Form} form The form to modify
 * @returns {Form} The form modified with errorsMessages
 */
function setFormErrors(formErrors, form) {
    var newForm = deepCopy_1.deepCopy(form);
    for (var _i = 0, _a = Object.entries(newForm); _i < _a.length; _i++) {
        var sectionName = _a[_i][0];
        for (var _b = 0, _c = Object.entries(formErrors); _b < _c.length; _b++) {
            var _d = _c[_b], fieldName = _d[0], errors = _d[1];
            var field = newForm[sectionName].questions[fieldName];
            if (!field || !errors) {
                continue;
            }
            var fieldOptions = field.fieldOptions || {};
            // If the field exists in our form and we
            // have errors to set, set errors
            if (typeof errors === 'string' || Array.isArray(errors)) {
                fieldOptions.errorMessages = errors;
            }
            else if (typeof errors === 'object') {
                // For each sub field in error
                for (var _e = 0, _f = Object.entries(errors); _e < _f.length; _e++) {
                    var _g = _f[_e], subFieldName = _g[0], subErrors = _g[1];
                    // Get the sub field fieldOptions or create it
                    var subFieldOptions = fieldOptions[subFieldName] || {};
                    // Add error messages to the sub field fieldOptions
                    subFieldOptions.errorMessages = subErrors;
                    // Update the field fieldOptions
                    fieldOptions[subFieldName] = subFieldOptions;
                }
            }
            else {
                continue;
            }
            // Set the new field fieldOptions to the form
            newForm[sectionName].questions[fieldName].fieldOptions = fieldOptions;
        }
    }
    return newForm;
}
exports.setFormErrors = setFormErrors;
